@@ -22,7 +22,7 @@ our @SVG_REGEX = qw/
 our @FUNCTIONS = qw/extract_path_info reverse_path create_path_string/;
 our @EXPORT_OK = (@FUNCTIONS, @SVG_REGEX);
 our %EXPORT_TAGS = (all => \@FUNCTIONS, regex => \@SVG_REGEX);
-our $VERSION = '0.31_01';
+our $VERSION = '0.31_02';
 
 use Carp;
 
@@ -158,16 +158,6 @@ my $comma_wsp = qr/$wsp+|$wsp*,$wsp*/;#|(?<=[0-9])(?=-)/;
 # regular expression is not following the SVG grammar, it is going our
 # own way.
 
-my $split_re = qr/
-		     (?:
-			 $comma_wsp
-		     |
-			 (?<!$e)(?=-)
-		     |
-			 (?<!$e)(?:\+)
-		     )
-		 /x;
-
 # Regular expressions to match numbers
 
 # Digit sequence
@@ -379,7 +369,10 @@ sub extract_path_info
     my @curves;
     while ( $path_pos < scalar @path ) {
         my $command = $path[$path_pos];
-        my $values = $path[$path_pos+1]//'';
+        my $values = $path[$path_pos+1];
+	if (! defined $values) {
+	    $values = '';
+	}
         my $original = "${command}${values}";
 	if ($original !~ /$moveto|$drawto_command/x) {
 	    warn "Cannot parse '$original' using moveto/drawto_command regex";
